@@ -1,13 +1,16 @@
+from numpy import zeros,nan
+
 def tsfill(valin,dtin,dtout):
     # purpose: regrid timeseries... fill missing timesteps in a timeseries with nan values, or leave out unwanted timesteps
     # valin: time series values
     # dtin: time steps of the timeseries
     # dtout: desired output timesteps
 
-    valout = zeros(len(dtout))
+    valout = zeros(len(dtout))*nan
+    lendtin = len(dtin)
     idtin = 0
     for idt,edt in enumerate(dtout):
-        while((dtin[idtin] < edt) & (idtin < len(dtin))):
+        while((dtin[idtin] < edt) & (idtin < (len(dtin)-1))):
             idtin = idtin + 1
     
         if edt == dtin[idtin]:
